@@ -61,8 +61,8 @@ AbstractProxyRequestCommand::AbstractProxyRequestCommand
   AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
   proxyRequest_(proxyRequest),
   httpConnection_
-  (new HttpConnection
-   (cuid, s, std::shared_ptr<SocketRecvBuffer>(new SocketRecvBuffer(s))))
+  (std::make_shared<HttpConnection>
+   (cuid, s, std::make_shared<SocketRecvBuffer>(s)))
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   disableReadCheckSocket();
