@@ -46,9 +46,9 @@ public:
 
   virtual ~AutoSaveCommand();
 
-  virtual void preProcess();
+  virtual void preProcess() CXX11_OVERRIDE;
 
-  virtual void process();
+  virtual void process() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
