@@ -41,7 +41,7 @@ namespace aria2 {
 
 class BtBitfieldMessage : public SimpleBtMessage {
 private:
-  unsigned char* bitfield_;
+  std::unique_ptr<unsigned char[]> bitfield_;
   size_t bitfieldLength_;
 public:
   BtBitfieldMessage();
@@ -56,7 +56,7 @@ public:
 
   void setBitfield(const unsigned char* bitfield, size_t bitfieldLength);
 
-  const unsigned char* getBitfield() const { return bitfield_; }
+  const unsigned char* getBitfield() const { return bitfield_.get(); }
 
   size_t getBitfieldLength() const { return bitfieldLength_; }
 
