@@ -39,26 +39,22 @@
 
 namespace aria2 {
 
-class BtChokeMessage;
-
-typedef SharedHandle<BtChokeMessage> BtChokeMessageHandle;
-
 class BtChokeMessage : public ZeroBtMessage {
 public:
   BtChokeMessage();
 
   static const uint8_t ID = 0;
 
-  static const std::string NAME;
+  static const char NAME[];
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  static SharedHandle<BtChokeMessage> create
+  static std::unique_ptr<BtChokeMessage> create
   (const unsigned char* data, size_t dataLength);
 
-  virtual bool sendPredicate() const;
+  virtual bool sendPredicate() const CXX11_OVERRIDE;
 
-  virtual void onSendComplete();
+  virtual std::unique_ptr<ProgressUpdate> getProgressUpdate() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
