@@ -39,8 +39,6 @@
 
 #include <string>
 
-#include "SharedHandle.h"
-
 namespace aria2 {
 
 class BtMessageValidator {
@@ -51,8 +49,6 @@ public:
   virtual void validate() = 0;
 };
 
-typedef SharedHandle<BtMessageValidator> BtMessageValidatorHandle;
-
 } // namespace aria2
 
 #endif // D_BT_MESSAGE_VALIDATOR_H
