@@ -61,20 +61,20 @@ public:
 
   static const uint8_t ID = 9;
 
-  static const std::string NAME;
+  static const char NAME[];
 
   uint16_t getPort() const { return port_; }
 
-  static SharedHandle<BtPortMessage> create
+  static std::unique_ptr<BtPortMessage> create
   (const unsigned char* data, size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual unsigned char* createMessage();
+  virtual unsigned char* createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
+  virtual size_t getMessageLength() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 
   void setLocalNode(DHTNode* localNode);
 
