@@ -36,13 +36,12 @@
 #define D_BT_RUNTIME_H
 
 #include "common.h"
-#include "SharedHandle.h"
 
 namespace aria2 {
 
 class BtRuntime {
 private:
-  off_t uploadLengthAtStartup_;
+  int64_t uploadLengthAtStartup_;
   bool halt_;
   int connections_;
   bool ready_;
@@ -57,11 +56,11 @@ public:
 
   ~BtRuntime();
 
-  off_t getUploadLengthAtStartup() const {
+  int64_t getUploadLengthAtStartup() const {
     return uploadLengthAtStartup_;
   }
 
-  void setUploadLengthAtStartup(off_t length) {
+  void setUploadLengthAtStartup(int64_t length) {
     uploadLengthAtStartup_ = length;
   }
 
@@ -107,8 +106,6 @@ public:
   static const int DEFAULT_MIN_PEERS = 40;
 };
 
-typedef SharedHandle<BtRuntime> BtRuntimeHandle;
-
 } // namespace aria2
 
 #endif // D_BT_RUNTIME_H
