@@ -32,11 +32,12 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CHECK_INTEGRITY_COMMAND_H_
-#define _D_CHECK_INTEGRITY_COMMAND_H_
+#ifndef D_CHECK_INTEGRITY_COMMAND_H
+#define D_CHECK_INTEGRITY_COMMAND_H
 
 #include "RealtimeCommand.h"
-#include "SharedHandle.h"
+
+#include <memory>
 
 namespace aria2 {
 
@@ -44,20 +45,20 @@ class CheckIntegrityEntry;
 
 class CheckIntegrityCommand : public RealtimeCommand {
 private:
-  SharedHandle<CheckIntegrityEntry> _entry;
+  CheckIntegrityEntry* entry_;
 public:
   CheckIntegrityCommand(cuid_t cuid,
                         RequestGroup* requestGroup,
                         DownloadEngine* e,
-                        const SharedHandle<CheckIntegrityEntry>& entry);
+                        CheckIntegrityEntry* entry);
 
   virtual ~CheckIntegrityCommand();
 
-  virtual bool executeInternal();
+  virtual bool executeInternal() CXX11_OVERRIDE;
 
-  virtual bool handleException(Exception& e);
+  virtual bool handleException(Exception& e) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_CHECK_INTEGRITY_COMMAND_H_
+#endif // D_CHECK_INTEGRITY_COMMAND_H
