@@ -56,13 +56,11 @@ private:
 
   DHTRoutingTable* routingTable_;
 public:
-  DHTAbstractMessage(const SharedHandle<DHTNode>& localNode,
-                     const SharedHandle<DHTNode>& remoteNode,
+  DHTAbstractMessage(const std::shared_ptr<DHTNode>& localNode,
+                     const std::shared_ptr<DHTNode>& remoteNode,
                      const std::string& transactionID = A2STR::NIL);
 
-  virtual ~DHTAbstractMessage();
-
-  virtual bool send();
+  virtual bool send() CXX11_OVERRIDE;
 
   virtual const std::string& getType() const = 0;
 
