@@ -39,13 +39,13 @@
 
 namespace aria2 {
 
-DHTMessageEntry::DHTMessageEntry(const SharedHandle<DHTMessage>& message,
-                                 time_t timeout,
-                                 const SharedHandle<DHTMessageCallback>& callback):
-  _message(message),
-  _timeout(timeout),
-  _callback(callback) {}
-
-DHTMessageEntry::~DHTMessageEntry() {}
+DHTMessageEntry::DHTMessageEntry
+(std::unique_ptr<DHTMessage> message,
+ time_t timeout,
+ std::unique_ptr<DHTMessageCallback> callback)
+  : message{std::move(message)},
+    timeout{timeout},
+    callback{std::move(callback)}
+{}
 
 } // namespace aria2
