@@ -43,55 +43,55 @@
 #include "DHTMessageDispatcher.h"
 #include "DHTMessageCallback.h"
 #include "PeerStorage.h"
-#include "BtRuntime.h"
 #include "util.h"
 #include "DHTBucket.h"
 #include "bittorrent_helper.h"
 #include "DHTPeerLookupTaskCallback.h"
 #include "DHTQueryMessage.h"
+#include "DHTGetPeersMessage.h"
+#include "DHTAnnouncePeerMessage.h"
+
 #include "fmt.h"
 
 namespace aria2 {
 
 DHTPeerLookupTask::DHTPeerLookupTask
-(const SharedHandle<DownloadContext>& downloadContext)
+(const std::shared_ptr<DownloadContext>& downloadContext,
+ uint16_t tcpPort)
   : DHTAbstractNodeLookupTask<DHTGetPeersReplyMessage>
-    (bittorrent::getInfoHash(downloadContext))
+    (bittorrent::getInfoHash(downloadContext)),
+    tcpPort_(tcpPort)
 {}
 
 void
 DHTPeerLookupTask::getNodesFromMessage
-(std::vector<SharedHandle<DHTNode> >& nodes,
+(std::vector<std::shared_ptr<DHTNode>>& nodes,
  const DHTGetPeersReplyMessage* message)
 {
-  const std::vector<SharedHandle<DHTNode> >& knodes =
-    message->getClosestKNodes();
-  nodes.insert(nodes.end(), knodes.begin(), knodes.end());
+  auto& knodes = message->getClosestKNodes();
+  nodes.insert(std::end(nodes), std::begin(knodes), std::end(knodes));
 }
-  
+
 void DHTPeerLookupTask::onReceivedInternal
 (const DHTGetPeersReplyMessage* message)
 {
-  SharedHandle<DHTNode> remoteNode = message->getRemoteNode();
+  std::shared_ptr<DHTNode> remoteNode = message->getRemoteNode();
   tokenStorage_[util::toHex(remoteNode->getID(), DHT_ID_LENGTH)] =
     message->getToken();
   peerStorage_->addPeer(message->getValues());
-  peers_.insert(peers_.end(),
-                message->getValues().begin(), message->getValues().end());
   A2_LOG_INFO(fmt("Received %lu peers.",
                   static_cast<unsigned long>(message->getValues().size())));
 }
-  
-SharedHandle<DHTMessage> DHTPeerLookupTask::createMessage
-(const SharedHandle<DHTNode>& remoteNode)
+
+std::unique_ptr<DHTMessage> DHTPeerLookupTask::createMessage
+(const std::shared_ptr<DHTNode>& remoteNode)
 {
   return getMessageFactory()->createGetPeersMessage(remoteNode, getTargetID());
 }
 
-SharedHandle<DHTMessageCallback> DHTPeerLookupTask::createCallback()
+std::unique_ptr<DHTMessageCallback> DHTPeerLookupTask::createCallback()
 {
-  return SharedHandle<DHTPeerLookupTaskCallback>
-    (new DHTPeerLookupTaskCallback(this));
+  return make_unique<DHTPeerLookupTaskCallback>(this);
 }
 
 void DHTPeerLookupTask::onFinish()
@@ -100,36 +100,29 @@ void DHTPeerLookupTask::onFinish()
                    util::toHex(getTargetID(), DHT_ID_LENGTH).c_str()));
   // send announce_peer message to K closest nodes
   size_t num = DHTBucket::K;
-  for(std::deque<SharedHandle<DHTNodeLookupEntry> >::const_iterator i =
-        getEntries().begin(), eoi = getEntries().end();
+  for(auto i = std::begin(getEntries()), eoi = std::end(getEntries());
       i != eoi && num > 0; ++i) {
     if(!(*i)->used) {
       continue;
     }
-    const SharedHandle<DHTNode>& node = (*i)->node;
+    auto& node = (*i)->node;
     std::string idHex = util::toHex(node->getID(), DHT_ID_LENGTH);
     std::string token = tokenStorage_[idHex];
     if(token.empty()) {
       A2_LOG_DEBUG(fmt("Token is empty for ID:%s", idHex.c_str()));
       continue;
     }
-    SharedHandle<DHTMessage> m =
-      getMessageFactory()->createAnnouncePeerMessage
-      (node,
-       getTargetID(), // this is infoHash
-       btRuntime_->getListenPort(),
-       token);
-    getMessageDispatcher()->addMessageToQueue(m);
+    getMessageDispatcher()->addMessageToQueue
+      (getMessageFactory()->createAnnouncePeerMessage
+       (node,
+        getTargetID(), // this is infoHash
+        tcpPort_,
+        token));
     --num;
   }
 }
 
-void DHTPeerLookupTask::setBtRuntime(const SharedHandle<BtRuntime>& btRuntime)
-{
-  btRuntime_ = btRuntime;
-}
-
-void DHTPeerLookupTask::setPeerStorage(const SharedHandle<PeerStorage>& ps)
+void DHTPeerLookupTask::setPeerStorage(const std::shared_ptr<PeerStorage>& ps)
 {
   peerStorage_ = ps;
 }
