@@ -42,17 +42,15 @@ namespace aria2 {
 
 class DHTPingMessage:public DHTQueryMessage {
 public:
-  DHTPingMessage(const SharedHandle<DHTNode>& localNode,
-                 const SharedHandle<DHTNode>& remoteNode,
+  DHTPingMessage(const std::shared_ptr<DHTNode>& localNode,
+                 const std::shared_ptr<DHTNode>& remoteNode,
                  const std::string& transactionID = A2STR::NIL);
 
-  virtual ~DHTPingMessage();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual void doReceivedAction();
+  virtual std::unique_ptr<Dict> getArgument() CXX11_OVERRIDE;
 
-  virtual SharedHandle<Dict> getArgument();
-
-  virtual const std::string& getMessageType() const;
+  virtual const std::string& getMessageType() const CXX11_OVERRIDE;
 
   static const std::string PING;
 };
