@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,37 +37,39 @@
 #include <cstring>
 
 #include "DHTNode.h"
-#include "bencode.h"
+#include "DHTMessageCallback.h"
 
 namespace aria2 {
 
 const std::string DHTPingReplyMessage::PING("ping");
 
-DHTPingReplyMessage::DHTPingReplyMessage(const SharedHandle<DHTNode>& localNode,
-					 const SharedHandle<DHTNode>& remoteNode,
-					 const unsigned char* id,
-					 const std::string& transactionID):
+DHTPingReplyMessage::DHTPingReplyMessage
+(const std::shared_ptr<DHTNode>& localNode,
+ const std::shared_ptr<DHTNode>& remoteNode,
+ const unsigned char* id,
+ const std::string& transactionID):
   DHTResponseMessage(localNode, remoteNode, transactionID)
 {
-  memcpy(_id, id, DHT_ID_LENGTH);
+  memcpy(id_, id, DHT_ID_LENGTH);
 }
 
-DHTPingReplyMessage::~DHTPingReplyMessage() {}
-
 void DHTPingReplyMessage::doReceivedAction() {}
 
-BDE DHTPingReplyMessage::getResponse()
+std::unique_ptr<Dict> DHTPingReplyMessage::getResponse()
 {
-  BDE rDict = BDE::dict();
-  rDict[DHTMessage::ID] = BDE(_id, DHT_ID_LENGTH);
+  auto rDict = Dict::g();
+  rDict->put(DHTMessage::ID, String::g(id_, DHT_ID_LENGTH));
   return rDict;
 }
 
-std::string DHTPingReplyMessage::getMessageType() const
+const std::string& DHTPingReplyMessage::getMessageType() const
 {
   return PING;
 }
 
-void DHTPingReplyMessage::validate() const {}
+void DHTPingReplyMessage::accept(DHTMessageCallback* callback)
+{
+  callback->visit(this);
+}
 
 } // namespace aria2
