@@ -39,8 +39,7 @@
 
 #include <vector>
 #include <deque>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
@@ -48,17 +47,17 @@ class DHTTask;
 
 class DHTTaskExecutor {
 private:
-  size_t numConcurrent_;
-  std::vector<SharedHandle<DHTTask> > execTasks_;
-  std::deque<SharedHandle<DHTTask> > queue_;
+  int numConcurrent_;
+  std::vector<std::shared_ptr<DHTTask> > execTasks_;
+  std::deque<std::shared_ptr<DHTTask> > queue_;
 public:
-  DHTTaskExecutor(size_t numConcurrent);
+  DHTTaskExecutor(int numConcurrent);
 
   ~DHTTaskExecutor();
 
   void update();
 
-  void addTask(const SharedHandle<DHTTask>& task)
+  void addTask(const std::shared_ptr<DHTTask>& task)
   {
     queue_.push_back(task);
   }
@@ -68,7 +67,7 @@ public:
     return execTasks_.size();
   }
 
-  size_t getNumConcurrent() const
+  int getNumConcurrent() const
   {
     return numConcurrent_;
   }
