@@ -40,8 +40,9 @@
 #include "bittorrent_helper.h"
 #include "DlAbortEx.h"
 #include "DHTConstants.h"
-#include "MessageDigestHelper.h"
-#include "StringFormat.h"
+#include "MessageDigest.h"
+#include "message_digest_helper.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -69,14 +70,14 @@ std::string DHTTokenTracker::generateToken
   int compactlen = bittorrent::packcompact(src+DHT_ID_LENGTH, ipaddr, port);
   if(compactlen == 0) {
     throw DL_ABORT_EX
-      (StringFormat("Token generation failed: ipaddr=%s, port=%u",
-                    ipaddr.c_str(), port).str());
+      (fmt("Token generation failed: ipaddr=%s, port=%u",
+           ipaddr.c_str(), port));
   }
   memcpy(src, infoHash, DHT_ID_LENGTH);
   memcpy(src+DHT_ID_LENGTH+COMPACT_LEN_IPV6, secret, SECRET_SIZE);
   unsigned char md[20];
-  MessageDigestHelper::digest(md, sizeof(md), MessageDigestContext::SHA1,
-                              src, sizeof(src));
+  message_digest::digest(md, sizeof(md), MessageDigest::sha1().get(),
+                         src, sizeof(src));
   return std::string(&md[0], &md[sizeof(md)]);
 }
 
@@ -90,8 +91,8 @@ bool DHTTokenTracker::validateToken(const std::string& token,
                                     const unsigned char* infoHash,
                                     const std::string& ipaddr, uint16_t port) const
 {
-  for(int i = 0; i < 2; ++i) {
-    if(generateToken(infoHash, ipaddr, port, secret_[i]) == token) {
+  for(auto & elem : secret_) {
+    if(generateToken(infoHash, ipaddr, port, elem) == token) {
       return true;
     }
   }
