@@ -58,11 +58,19 @@ class FileEntry;
 class DownloadContext
 {
 private:
+  std::unique_ptr<Signature> signature_;
+
+  RequestGroup* ownerRequestGroup_;
+
+  std::vector<std::unique_ptr<ContextAttribute> > attrs_;
+
   std::vector<std::shared_ptr<FileEntry> > fileEntries_;
 
   std::vector<std::string> pieceHashes_;
 
-  int32_t pieceLength_;
+  NetStat netStat_;
+
+  Timer downloadStopTime_;
 
   std::string pieceHashType_;
 
@@ -70,24 +78,18 @@ private:
 
   std::string hashType_;
 
-  bool checksumVerified_;
-
   std::string basePath_;
 
+  int32_t pieceLength_;
+
+  bool checksumVerified_;
+
   bool knowsTotalLength_;
 
-  RequestGroup* ownerRequestGroup_;
-
-  std::vector<std::unique_ptr<ContextAttribute> > attrs_;
-
-  NetStat netStat_;
-
-  Timer downloadStopTime_;
-
-  std::unique_ptr<Signature> signature_;
   // This member variable is required to avoid to use parse Metalink
   // (including both Metalink XML and Metalink/HTTP) twice.
   bool acceptMetalink_;
+
 public:
   DownloadContext();
 
@@ -95,7 +97,7 @@ public:
   // should be escaped with util::escapePath(...).
   DownloadContext(int32_t pieceLength,
                   int64_t totalLength,
-                  const std::string& path = A2STR::NIL);
+                  std::string path = A2STR::NIL);
 
   ~DownloadContext();
 
@@ -181,7 +183,7 @@ public:
   }
 
   // sgl must be normalized before the call.
-  void setFileFilter(SegList<int>& sgl);
+  void setFileFilter(SegList<int> sgl);
 
   // Sets file path for specified index. index starts from 1. The
   // index is the same used in setFileFilter(). path is not escaped by
