@@ -36,7 +36,6 @@
 #define D_FILL_REQUEST_GROUP_COMMAND_H
 
 #include "Command.h"
-#include "SharedHandle.h"
 #include "a2time.h"
 
 namespace aria2 {
@@ -52,7 +51,7 @@ public:
 
   virtual ~FillRequestGroupCommand();
 
-  virtual bool execute();
+  virtual bool execute() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
