@@ -203,7 +203,7 @@ std::shared_ptr<SocketCore> FtpConnection::createServerSocket()
 {
   std::pair<std::string, uint16_t> addrinfo;
   socket_->getAddrInfo(addrinfo);
-  std::shared_ptr<SocketCore> serverSocket(new SocketCore());
+  auto serverSocket = std::make_shared<SocketCore>();
   serverSocket->bind(addrinfo.first.c_str(), 0, AF_UNSPEC);
   serverSocket->beginListen();
   return serverSocket;
@@ -295,7 +295,7 @@ int FtpConnection::getStatus(const std::string& response) const
   }
 }
 
-// Returns the length of the reponse if the whole response has been received.
+// Returns the length of the response if the whole response has been received.
 // The length includes \r\n.
 // If the whole response has not been received, then returns std::string::npos.
 std::string::size_type
