@@ -60,6 +60,10 @@
 #include "FtpNegotiationConnectChain.h"
 #include "FtpTunnelRequestConnectChain.h"
 #include "HttpRequestConnectChain.h"
+#ifdef HAVE_LIBSSH2
+# include "SftpNegotiationConnectChain.h"
+# include "SftpNegotiationCommand.h"
+#endif // HAVE_LIBSSH2
 
 namespace aria2 {
 
@@ -82,6 +86,7 @@ std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommandProxied
   std::shared_ptr<SocketCore> pooledSocket;
   std::string proxyMethod = resolveProxyMethod(getRequest()->getProtocol());
 
+  // sftp always use tunnel mode
   if(proxyMethod == V_GET) {
     pooledSocket = getDownloadEngine()->popPooledSocket
       (getRequest()->getHost(), getRequest()->getPort(),
@@ -113,13 +118,9 @@ std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommandProxied
     if(proxyMethod == V_GET) {
       // Use GET for FTP via HTTP proxy.
       getRequest()->setMethod(Request::METHOD_GET);
-      std::shared_ptr<HttpRequestConnectChain> chain
-        (new HttpRequestConnectChain());
-      c->setControlChain(chain);
+      c->setControlChain(std::make_shared<HttpRequestConnectChain>());
     } else if(proxyMethod == V_TUNNEL) {
-      std::shared_ptr<FtpTunnelRequestConnectChain> chain
-        (new FtpTunnelRequestConnectChain());
-      c->setControlChain(chain);
+      c->setControlChain(std::make_shared<FtpTunnelRequestConnectChain>());
     } else {
       // Unreachable
       assert(0);
@@ -131,18 +132,33 @@ std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommandProxied
 
   setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
   if(proxyMethod == V_TUNNEL) {
+#ifdef HAVE_LIBSSH2
+    if (getRequest()->getProtocol() == "sftp") {
+      return make_unique<SftpNegotiationCommand>
+        (getCuid(),
+         getRequest(),
+         getFileEntry(),
+         getRequestGroup(),
+         getDownloadEngine(),
+         pooledSocket,
+         SftpNegotiationCommand::SEQ_SFTP_OPEN);
+    }
+#endif // HAVE_LIBSSH2
+
     // options contains "baseWorkingDir"
     return make_unique<FtpNegotiationCommand>
       (getCuid(),
-        getRequest(),
-        getFileEntry(),
-        getRequestGroup(),
-        getDownloadEngine(),
-        pooledSocket,
-        FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
-        options);
+       getRequest(),
+       getFileEntry(),
+       getRequestGroup(),
+       getDownloadEngine(),
+       pooledSocket,
+       FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
+       options);
   }
 
+  assert(getRequest()->getProtocol() == "ftp");
+
   if(proxyMethod != V_GET) {
     assert(0);
     return nullptr;
@@ -150,10 +166,9 @@ std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommandProxied
 
   // Use GET for FTP via HTTP proxy.
   getRequest()->setMethod(Request::METHOD_GET);
-  std::shared_ptr<SocketRecvBuffer> socketRecvBuffer
-    (new SocketRecvBuffer(pooledSocket));
-  std::shared_ptr<HttpConnection> hc
-    (new HttpConnection(getCuid(), pooledSocket, socketRecvBuffer));
+  auto socketRecvBuffer = std::make_shared<SocketRecvBuffer>(pooledSocket);
+  auto hc = std::make_shared<HttpConnection>(getCuid(), pooledSocket,
+                                             socketRecvBuffer);
 
   auto c = make_unique<HttpRequestCommand>(getCuid(),
                                            getRequest(),
@@ -185,31 +200,51 @@ std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommandPlain
     getSocket()->establishConnection(addr, port);
     getRequest()->setConnectedAddrInfo(hostname, addr, port);
     auto c = make_unique<ConnectCommand>(getCuid(),
-                                          getRequest(),
-                                          nullptr,
-                                          getFileEntry(),
-                                          getRequestGroup(),
-                                          getDownloadEngine(),
-                                          getSocket());
-    std::shared_ptr<FtpNegotiationConnectChain> chain
-      (new FtpNegotiationConnectChain());
-    c->setControlChain(chain);
+                                         getRequest(),
+                                         nullptr,
+                                         getFileEntry(),
+                                         getRequestGroup(),
+                                         getDownloadEngine(),
+                                         getSocket());
+
+    if(getRequest()->getProtocol() == "sftp") {
+#ifdef HAVE_LIBSSH2
+      c->setControlChain(std::make_shared<SftpNegotiationConnectChain>());
+#else // !HAVE_LIBSSH2
+      assert(0);
+#endif // !HAVE_LIBSSH2
+    } else {
+      c->setControlChain(std::make_shared<FtpNegotiationConnectChain>());
+    }
     setupBackupConnection(hostname, addr, port, c.get());
     return std::move(c);
   }
 
-  // options contains "baseWorkingDir"
-  auto command = make_unique<FtpNegotiationCommand>
-    (getCuid(),
-      getRequest(),
-      getFileEntry(),
-      getRequestGroup(),
-      getDownloadEngine(),
-      pooledSocket,
-      FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
-      options);
   setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
-  return std::move(command);
+
+#ifdef HAVE_LIBSSH2
+  if (getRequest()->getProtocol() == "sftp") {
+    return make_unique<SftpNegotiationCommand>
+      (getCuid(),
+       getRequest(),
+       getFileEntry(),
+       getRequestGroup(),
+       getDownloadEngine(),
+       pooledSocket,
+       SftpNegotiationCommand::SEQ_SFTP_OPEN);
+  }
+#endif // HAVE_LIBSSH2
+
+  // options contains "baseWorkingDir"
+  return make_unique<FtpNegotiationCommand>
+    (getCuid(),
+     getRequest(),
+     getFileEntry(),
+     getRequestGroup(),
+     getDownloadEngine(),
+     pooledSocket,
+     FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
+     options);
 }
 
 std::unique_ptr<Command> FtpInitiateConnectionCommand::createNextCommand
