@@ -124,13 +124,14 @@ void HttpConnection::sendRequest
 (std::unique_ptr<HttpRequest> httpRequest)
 {
   auto req = httpRequest->createRequest();
-  sendRequest(std::move(httpRequest), req);
+  sendRequest(std::move(httpRequest), std::move(req));
 }
 
 void HttpConnection::sendProxyRequest
 (std::unique_ptr<HttpRequest> httpRequest)
 {
-  sendRequest(std::move(httpRequest), httpRequest->createProxyRequest());
+  auto req = httpRequest->createProxyRequest();
+  sendRequest(std::move(httpRequest), std::move(req));
 }
 
 std::unique_ptr<HttpResponse> HttpConnection::receiveResponse()
@@ -156,12 +157,12 @@ std::unique_ptr<HttpResponse> HttpConnection::receiveResponse()
     httpResponse->setHttpHeader(proc->getResult());
     httpResponse->setHttpRequest(outstandingHttpRequests_.front()->
                                  popHttpRequest());
-    socketRecvBuffer_->shiftBuffer(proc->getLastBytesProcessed());
+    socketRecvBuffer_->drain(proc->getLastBytesProcessed());
     outstandingHttpRequests_.pop_front();
     return httpResponse;
   }
 
-  socketRecvBuffer_->shiftBuffer(proc->getLastBytesProcessed());
+  socketRecvBuffer_->drain(proc->getLastBytesProcessed());
   return nullptr;
 }
 
