@@ -58,15 +58,15 @@ namespace aria2 {
 const std::string HttpRequest::USER_AGENT("aria2");
 
 HttpRequest::HttpRequest()
-  : contentEncodingEnabled_(true),
-    userAgent_(USER_AGENT),
-    acceptMetalink_(false),
-    cookieStorage_(nullptr),
+  : cookieStorage_(nullptr),
     authConfigFactory_(nullptr),
     option_(nullptr),
+    endOffsetOverride_(0),
+    userAgent_(USER_AGENT),
+    contentEncodingEnabled_(true),
+    acceptMetalink_(false),
     noCache_(true),
-    acceptGzip_(false),
-    endOffsetOverride_(0)
+    acceptGzip_(false)
 {}
 
 HttpRequest::~HttpRequest() {}
