@@ -125,13 +125,11 @@ public:
   void getMetalinKHttpEntries(std::vector<MetalinkHttpEntry>& result,
                               const std::shared_ptr<Option>& option) const;
 
-#ifdef ENABLE_MESSAGE_DIGEST
   // Returns all digests specified in Digest header field.  Sort
   // strong algorithm first. Strength is defined in MessageDigest. If
   // several same digest algorithms are available, but they have
   // different value, they are all ignored.
   void getDigest(std::vector<Checksum>& result) const;
-#endif // ENABLE_MESSAGE_DIGEST
 
 };
 
