@@ -62,7 +62,7 @@ std::unique_ptr<util::security::HMAC> HttpServer::hmac_;
 
 HttpServer::HttpServer(const std::shared_ptr<SocketCore>& socket)
  : socket_(socket),
-   socketRecvBuffer_(new SocketRecvBuffer(socket_)),
+   socketRecvBuffer_(std::make_shared<SocketRecvBuffer>(socket_)),
    socketBuffer_(socket),
    headerProcessor_(make_unique<HttpHeaderProcessor>
                     (HttpHeaderProcessor::SERVER_PARSER)),
@@ -142,7 +142,7 @@ bool HttpServer::receiveRequest()
     lastRequestHeader_ = headerProcessor_->getResult();
     A2_LOG_INFO(fmt("HTTP Server received request\n%s",
                     headerProcessor_->getHeaderString().c_str()));
-    socketRecvBuffer_->shiftBuffer(headerProcessor_->getLastBytesProcessed());
+    socketRecvBuffer_->drain(headerProcessor_->getLastBytesProcessed());
     bodyConsumed_ = 0;
     if(setupResponseRecv() < 0) {
       A2_LOG_INFO("Request path is invaild. Ignore the request body.");
@@ -175,7 +175,7 @@ bool HttpServer::receiveRequest()
     }
     return true;
   } else {
-    socketRecvBuffer_->shiftBuffer(headerProcessor_->getLastBytesProcessed());
+    socketRecvBuffer_->drain(headerProcessor_->getLastBytesProcessed());
     return false;
   }
 }
@@ -197,7 +197,7 @@ bool HttpServer::receiveBody()
   if(lastBody_) {
     lastBody_->writeData(socketRecvBuffer_->getBuffer(), length, 0);
   }
-  socketRecvBuffer_->shiftBuffer(length);
+  socketRecvBuffer_->drain(length);
   bodyConsumed_ += length;
   return lastContentLength_ == bodyConsumed_;
 }
@@ -341,7 +341,7 @@ int HttpServer::setupResponseRecv()
     if(path == "/jsonrpc") {
       if(reqType_ != RPC_TYPE_JSON) {
         reqType_ = RPC_TYPE_JSON;
-        lastBody_.reset(new json::JsonDiskWriter());
+        lastBody_ = make_unique<json::JsonDiskWriter>();
       }
       return 0;
     }
@@ -349,7 +349,7 @@ int HttpServer::setupResponseRecv()
     if(path == "/rpc") {
       if(reqType_ != RPC_TYPE_XML) {
         reqType_ = RPC_TYPE_XML;
-        lastBody_.reset(new rpc::XmlRpcDiskWriter());
+        lastBody_ = make_unique<rpc::XmlRpcDiskWriter>();
       }
       return 0;
     }
