@@ -91,8 +91,10 @@ bool InitiateConnectionCommand::executeInternal() {
     return false;
   }
   try {
-    getDownloadEngine()->addCommand(createNextCommand(hostname, ipaddr, port,
-                                                      addrs, proxyRequest));
+    auto c = createNextCommand(hostname, ipaddr, port, addrs, proxyRequest);
+    c->setStatus(Command::STATUS_ONESHOT_REALTIME);
+    getDownloadEngine()->setNoWait(true);
+    getDownloadEngine()->addCommand(std::move(c));
     return true;
   } catch(RecoverableException& ex) {
     // Catch exception and retry another address.
@@ -133,7 +135,7 @@ InitiateConnectionCommand::createBackupIPv4ConnectCommand
 (const std::string& hostname, const std::string& ipaddr, uint16_t port,
  Command* mainCommand)
 {
-  // Prepare IPv4 backup connection attemp in "Happy Eyeballs"
+  // Prepare IPv4 backup connection attempt in "Happy Eyeballs"
   // fashion.
   std::shared_ptr<BackupConnectInfo> info;
   char buf[sizeof(in6_addr)];
@@ -147,7 +149,7 @@ InitiateConnectionCommand::createBackupIPv4ConnectCommand
   for(std::vector<std::string>::const_iterator i = addrs.begin(),
         eoi = addrs.end(); i != eoi; ++i) {
     if(inetPton(AF_INET, (*i).c_str(), &buf) == 0) {
-      info.reset(new BackupConnectInfo());
+      info = std::make_shared<BackupConnectInfo>();
       auto command = make_unique<BackupIPv4ConnectCommand>
         (getDownloadEngine()->newCUID(), *i, port, info, mainCommand,
          getRequestGroup(), getDownloadEngine());
