@@ -58,8 +58,8 @@ IteratableChunkChecksumValidator::IteratableChunkChecksumValidator
  const std::shared_ptr<PieceStorage>& pieceStorage)
   : dctx_(dctx),
     pieceStorage_(pieceStorage),
-    bitfield_(new BitfieldMan(dctx_->getPieceLength(),
-                              dctx_->getTotalLength())),
+    bitfield_(make_unique<BitfieldMan>(dctx_->getPieceLength(),
+                                       dctx_->getTotalLength())),
     currentIndex_(0)
 {}
 
