@@ -37,13 +37,15 @@
 
 #include <nettle/nettle-meta.h>
 
+#include "Adler32MessageDigestImpl.h"
+
 namespace aria2 {
 
 namespace {
 template<const nettle_hash* hash>
 class MessageDigestBase : public MessageDigestImpl {
 public:
-  MessageDigestBase() : ctx_(new char[hash->context_size]) {
+  MessageDigestBase() : ctx_(make_unique<char[]>(hash->context_size)) {
     reset();
   }
   virtual ~MessageDigestBase() {}
@@ -85,7 +87,7 @@ typedef MessageDigestBase<&nettle_sha512> MessageDigestSHA512;
 
 std::unique_ptr<MessageDigestImpl> MessageDigestImpl::sha1()
 {
-  return std::unique_ptr<MessageDigestImpl>(new MessageDigestSHA1());
+  return make_unique<MessageDigestSHA1>();
 }
 
 MessageDigestImpl::hashes_t MessageDigestImpl::hashes = {
@@ -95,6 +97,7 @@ MessageDigestImpl::hashes_t MessageDigestImpl::hashes = {
   { "sha-384", make_hi<MessageDigestSHA384>() },
   { "sha-512", make_hi<MessageDigestSHA512>() },
   { "md5", make_hi<MessageDigestMD5>() },
+  ADLER32_MESSAGE_DIGEST
 };
 
 } // namespace aria2
