@@ -81,12 +81,12 @@ namespace {
 
 namespace aria2 {
 
-TLSContext* TLSContext::make(TLSSessionSide side)
+TLSContext* TLSContext::make(TLSSessionSide side, TLSVersion minVer)
 {
-  return new OpenSSLTLSContext(side);
+  return new OpenSSLTLSContext(side, minVer);
 }
 
-OpenSSLTLSContext::OpenSSLTLSContext(TLSSessionSide side)
+OpenSSLTLSContext::OpenSSLTLSContext(TLSSessionSide side, TLSVersion minVer)
   : sslCtx_(nullptr),
     side_(side),
     verifyPeer_(true)
@@ -100,23 +100,54 @@ OpenSSLTLSContext::OpenSSLTLSContext(TLSSessionSide side)
                      ERR_error_string(ERR_get_error(), nullptr)));
     return;
   }
+
+  long ver_opts = 0;
+  switch(minVer) {
+  case TLS_PROTO_TLS12:
+    ver_opts |= SSL_OP_NO_TLSv1_1;
+    // fall through
+  case TLS_PROTO_TLS11:
+    ver_opts |= SSL_OP_NO_TLSv1;
+    // fall through
+  case TLS_PROTO_TLS10:
+    ver_opts |= SSL_OP_NO_SSLv3;
+  default:
+    break;
+  };
+
   // Disable SSLv2 and enable all workarounds for buggy servers
-  SSL_CTX_set_options(sslCtx_, SSL_OP_ALL | SSL_OP_NO_SSLv2
+  SSL_CTX_set_options(sslCtx_, SSL_OP_ALL | SSL_OP_NO_SSLv2 | ver_opts
+#ifdef SSL_OP_SINGLE_ECDH_USE
+                      | SSL_OP_SINGLE_ECDH_USE
+#endif // SSL_OP_SINGLE_ECDH_USE
 #ifdef SSL_OP_NO_COMPRESSION
                       | SSL_OP_NO_COMPRESSION
 #endif // SSL_OP_NO_COMPRESSION
                       );
   SSL_CTX_set_mode(sslCtx_, SSL_MODE_AUTO_RETRY);
   SSL_CTX_set_mode(sslCtx_, SSL_MODE_ENABLE_PARTIAL_WRITE);
-  #ifdef SSL_MODE_RELEASE_BUFFERS
+#ifdef SSL_MODE_RELEASE_BUFFERS
   /* keep memory usage low */
   SSL_CTX_set_mode(sslCtx_, SSL_MODE_RELEASE_BUFFERS);
-  #endif
+#endif
   if(SSL_CTX_set_cipher_list(sslCtx_, "HIGH:!aNULL:!eNULL") == 0) {
     good_ = false;
     A2_LOG_ERROR(fmt("SSL_CTX_set_cipher_list() failed. Cause: %s",
                      ERR_error_string(ERR_get_error(), nullptr)));
   }
+
+#if OPENSSL_VERSION_NUMBER >= 0x0090800fL
+#ifndef OPENSSL_NO_ECDH
+  auto ecdh = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
+  if(ecdh == nullptr) {
+    A2_LOG_WARN(fmt("Failed to enable ECDHE cipher suites. Cause: %s",
+                    ERR_error_string(ERR_get_error(), nullptr)));
+  } else {
+    SSL_CTX_set_tmp_ecdh(sslCtx_, ecdh);
+    EC_KEY_free(ecdh);
+  }
+#endif // OPENSSL_NO_ECDH
+#endif // OPENSSL_VERSION_NUMBER >= 0x0090800fL
 }
 
 OpenSSLTLSContext::~OpenSSLTLSContext()
