@@ -51,9 +51,12 @@ private:
   static bool consoleOutput_;
   static Logger::LEVEL logLevel_;
   static Logger::LEVEL consoleLogLevel_;
+  static bool colorOutput_;
 
   static void openLogger(const std::shared_ptr<Logger>& logger);
 
+  static void adjustDependentLevels();
+
   LogFactory();
 public:
   /**
@@ -99,6 +102,12 @@ public:
    */
   static void setConsoleLogLevel(const std::string& level);
 
+  /**
+   * Enable color output if |enabled| is true. By default, color
+   * output is enabled for terminal.
+   */
+  static void setColorOutput(bool enabled);
+
   /**
    * Releases used resources
    */
