@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,7 +37,8 @@
 
 namespace aria2 {
 
-static size_t getStartIndex
+namespace {
+size_t getStartIndex
 (size_t from, const unsigned char* bitfield, size_t nbits)
 {
   while(from < nbits && !bitfield::test(bitfield, nbits, from)) {
@@ -49,8 +50,10 @@ static size_t getStartIndex
     return from;
   }
 }
+} // namespace
 
-static size_t getEndIndex
+namespace {
+size_t getEndIndex
 (size_t from, const unsigned char* bitfield, size_t nbits)
 {
   while(from < nbits && bitfield::test(bitfield, nbits, from)) {
@@ -58,6 +61,7 @@ static size_t getEndIndex
   }
   return from;
 }
+} // namespace
 
 bool LongestSequencePieceSelector::select
 (size_t& index, const unsigned char* bitfield, size_t nbits) const
@@ -85,16 +89,4 @@ bool LongestSequencePieceSelector::select
   }
 }
 
-void LongestSequencePieceSelector::addPieceStats
-(const unsigned char* bitfield, size_t bitfieldLength) {}
-
-void LongestSequencePieceSelector::subtractPieceStats
-(const unsigned char* bitfield, size_t bitfieldLength) {}
-
-void LongestSequencePieceSelector::updatePieceStats
-(const unsigned char* newBitfield, size_t newBitfieldLength,
- const unsigned char* oldBitfield) {}
-
-void LongestSequencePieceSelector::addPieceStats(size_t index) {}
-
 } // namespace aria2
