@@ -228,7 +228,7 @@ Metalink2RequestGroup::createRequestGroup
         torrentRg->clearPreDownloadHandler();
         torrentRg->clearPostDownloadHandler();
         // remove "metalink" from Accept Type list to avoid loop in
-        // tranparent metalink
+        // transparent metalink
         torrentRg->getDownloadContext()->setAcceptMetalink(false);
         // make it in-memory download
         torrentRg->addPreDownloadHandler
@@ -246,6 +246,10 @@ Metalink2RequestGroup::createRequestGroup
       auto entry = mes[0];
       A2_LOG_INFO(fmt(MSG_METALINK_QUEUEING, entry->getPath().c_str()));
       entry->reorderResourcesByPriority();
+      for(auto& mr : entry->resources) {
+        A2_LOG_DEBUG(fmt("priority=%d url=%s",
+                         mr->priority, mr->url.c_str()));
+      }
       std::vector<std::string> uris;
       std::for_each(std::begin(entry->resources), std::end(entry->resources),
                     AccumulateNonP2PUri(uris));
@@ -327,10 +331,10 @@ Metalink2RequestGroup::createRequestGroup
 
     removeOneshotOption(option);
     // remove "metalink" from Accept Type list to avoid loop in
-    // tranparent metalink
+    // transparent metalink
     dctx->setAcceptMetalink(false);
 #ifdef ENABLE_BITTORRENT
-    // Inject depenency between rg and torrentRg here if
+    // Inject dependency between rg and torrentRg here if
     // torrentRg is true
     if(torrentRg) {
       auto dep = std::make_shared<BtDependency>(rg.get(), torrentRg);
