@@ -46,11 +46,9 @@
 #include "uri.h"
 #include "Signature.h"
 #include "util.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "Checksum.h"
-# include "ChunkChecksum.h"
-# include "MessageDigest.h"
-#endif // ENABLE_MESSAGE_DIGEST
+#include "Checksum.h"
+#include "ChunkChecksum.h"
+#include "MessageDigest.h"
 #ifdef ENABLE_BITTORRENT
 # include "magnet.h"
 #endif // ENABLE_BITTORRENT
@@ -78,14 +76,12 @@ void MetalinkParserController::newEntryTransaction()
   tEntry_ = make_unique<MetalinkEntry>();
   tResource_.reset();
   tMetaurl_.reset();
-#ifdef ENABLE_MESSAGE_DIGEST
   tChecksum_.reset();
   tChunkChecksumV4_.reset();
   tChunkChecksum_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setFileNameOfEntry(const std::string& filename)
+void MetalinkParserController::setFileNameOfEntry(std::string filename)
 {
   if(!tEntry_) {
     return;
@@ -109,28 +105,28 @@ void MetalinkParserController::setFileLengthOfEntry(int64_t length)
   tEntry_->sizeKnown = true;
 }
 
-void MetalinkParserController::setVersionOfEntry(const std::string& version)
+void MetalinkParserController::setVersionOfEntry(std::string version)
 {
   if(!tEntry_) {
     return;
   }
-  tEntry_->version = version;
+  tEntry_->version = std::move(version);
 }
 
-void MetalinkParserController::setLanguageOfEntry(const std::string& language)
+void MetalinkParserController::setLanguageOfEntry(std::string language)
 {
   if(!tEntry_) {
     return;
   }
-  tEntry_->languages.push_back(language);
+  tEntry_->languages.push_back(std::move(language));
 }
 
-void MetalinkParserController::setOSOfEntry(const std::string& os)
+void MetalinkParserController::setOSOfEntry(std::string os)
 {
   if(!tEntry_) {
     return;
   }
-  tEntry_->oses.push_back(os);
+  tEntry_->oses.push_back(std::move(os));
 }
 
 void MetalinkParserController::setMaxConnectionsOfEntry(int maxConnections)
@@ -174,7 +170,7 @@ void MetalinkParserController::newResourceTransaction()
   tResource_ = make_unique<MetalinkResource>();
 }
 
-void MetalinkParserController::setURLOfResource(const std::string& url)
+void MetalinkParserController::setURLOfResource(std::string url)
 {
   if(!tResource_) {
     return;
@@ -182,21 +178,22 @@ void MetalinkParserController::setURLOfResource(const std::string& url)
   std::string u = uri::joinUri(baseUri_, url);
   uri_split_result us;
   if(uri_split(&us, u.c_str()) == 0) {
-    tResource_->url = u;
+    tResource_->url = std::move(u);
     if(tResource_->type == MetalinkResource::TYPE_UNKNOWN) {
-      setTypeOfResource(uri::getFieldString(us, USR_SCHEME, u.c_str()));
+      setTypeOfResource(uri::getFieldString(us, USR_SCHEME,
+                                            tResource_->url.c_str()));
     }
   } else {
-    tResource_->url = url;
+    tResource_->url = std::move(url);
   }
 }
 
-void MetalinkParserController::setTypeOfResource(const std::string& type)
+void MetalinkParserController::setTypeOfResource(std::string type)
 {
   if(!tResource_) {
     return;
   }
-  if(type == "ftp") {
+  if(type == "ftp" || type == "sftp") {
     tResource_->type = MetalinkResource::TYPE_FTP;
   } else if(type == "http") {
     tResource_->type = MetalinkResource::TYPE_HTTP;
@@ -210,12 +207,12 @@ void MetalinkParserController::setTypeOfResource(const std::string& type)
   }
 }
 
-void MetalinkParserController::setLocationOfResource(const std::string& location)
+void MetalinkParserController::setLocationOfResource(std::string location)
 {
   if(!tResource_) {
     return;
   }
-  tResource_->location = location;
+  tResource_->location = std::move(location);
 }
 
 void MetalinkParserController::setPriorityOfResource(int priority)
@@ -262,32 +259,27 @@ void MetalinkParserController::cancelResourceTransaction()
 
 void MetalinkParserController::newChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tEntry_) {
     return;
   }
   tChecksum_ = make_unique<Checksum>();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setTypeOfChecksum(const std::string& type)
+void MetalinkParserController::setTypeOfChecksum(std::string type)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChecksum_) {
     return;
   }
   std::string calgo = MessageDigest::getCanonicalHashType(type);
   if(MessageDigest::supports(calgo)) {
-    tChecksum_->setHashType(calgo);
+    tChecksum_->setHashType(std::move(calgo));
   } else {
     cancelChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setHashOfChecksum(const std::string& md)
+void MetalinkParserController::setHashOfChecksum(std::string md)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChecksum_) {
     return;
   }
@@ -296,12 +288,10 @@ void MetalinkParserController::setHashOfChecksum(const std::string& md)
   } else {
     cancelChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::commitChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChecksum_) {
     return;
   }
@@ -311,45 +301,37 @@ void MetalinkParserController::commitChecksumTransaction()
     tEntry_->checksum = std::move(tChecksum_);
   }
   tChecksum_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::cancelChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   tChecksum_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::newChunkChecksumTransactionV4()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tEntry_) {
     return;
   }
   tChunkChecksumV4_ = make_unique<ChunkChecksum>();
   tempChunkChecksumsV4_.clear();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setTypeOfChunkChecksumV4(const std::string& type)
+void MetalinkParserController::setTypeOfChunkChecksumV4(std::string type)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksumV4_) {
     return;
   }
   std::string calgo = MessageDigest::getCanonicalHashType(type);
   if(MessageDigest::supports(calgo)) {
-    tChunkChecksumV4_->setHashType(calgo);
+    tChunkChecksumV4_->setHashType(std::move(calgo));
   } else {
     cancelChunkChecksumTransactionV4();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::setLengthOfChunkChecksumV4(size_t length)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksumV4_) {
     return;
   }
@@ -358,12 +340,10 @@ void MetalinkParserController::setLengthOfChunkChecksumV4(size_t length)
   } else {
     cancelChunkChecksumTransactionV4();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::addHashOfChunkChecksumV4(const std::string& md)
+void MetalinkParserController::addHashOfChunkChecksumV4(std::string md)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksumV4_) {
     return;
   }
@@ -372,12 +352,10 @@ void MetalinkParserController::addHashOfChunkChecksumV4(const std::string& md)
   } else {
     cancelChunkChecksumTransactionV4();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::commitChunkChecksumTransactionV4()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksumV4_) {
     return;
   }
@@ -388,45 +366,37 @@ void MetalinkParserController::commitChunkChecksumTransactionV4()
     tEntry_->chunkChecksum = std::move(tChunkChecksumV4_);
   }
   tChunkChecksumV4_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::cancelChunkChecksumTransactionV4()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   tChunkChecksumV4_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::newChunkChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tEntry_) {
     return;
   }
   tChunkChecksum_ = make_unique<ChunkChecksum>();
   tempChunkChecksums_.clear();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setTypeOfChunkChecksum(const std::string& type)
+void MetalinkParserController::setTypeOfChunkChecksum(std::string type)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
   std::string calgo = MessageDigest::getCanonicalHashType(type);
   if(MessageDigest::supports(calgo)) {
-    tChunkChecksum_->setHashType(calgo);
+    tChunkChecksum_->setHashType(std::move(calgo));
   } else {
     cancelChunkChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::setLengthOfChunkChecksum(size_t length)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
@@ -435,36 +405,31 @@ void MetalinkParserController::setLengthOfChunkChecksum(size_t length)
   } else {
     cancelChunkChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::addHashOfChunkChecksum(size_t order, const std::string& md)
+void MetalinkParserController::addHashOfChunkChecksum(size_t order,
+                                                      std::string md)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
   if(MessageDigest::isValidHash(tChunkChecksum_->getHashType(), md)) {
-    tempChunkChecksums_.push_back(std::make_pair(order, md));
+    tempChunkChecksums_.push_back(std::make_pair(order, std::move(md)));
   } else {
     cancelChunkChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::createNewHashOfChunkChecksum(size_t order)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
   tempHashPair_.first = order;
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
-void MetalinkParserController::setMessageDigestOfChunkChecksum(const std::string& md)
+void MetalinkParserController::setMessageDigestOfChunkChecksum(std::string md)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
@@ -473,22 +438,18 @@ void MetalinkParserController::setMessageDigestOfChunkChecksum(const std::string
   } else {
     cancelChunkChecksumTransaction();
   }
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::addHashOfChunkChecksum()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
   tempChunkChecksums_.push_back(tempHashPair_);
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::commitChunkChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   if(!tChunkChecksum_) {
     return;
   }
@@ -506,14 +467,11 @@ void MetalinkParserController::commitChunkChecksumTransaction()
     tEntry_->chunkChecksum = std::move(tChunkChecksum_);
   }
   tChunkChecksum_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::cancelChunkChecksumTransaction()
 {
-#ifdef ENABLE_MESSAGE_DIGEST
   tChunkChecksum_.reset();
-#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::newSignatureTransaction()
@@ -524,28 +482,28 @@ void MetalinkParserController::newSignatureTransaction()
   tSignature_ = make_unique<Signature>();
 }
 
-void MetalinkParserController::setTypeOfSignature(const std::string& type)
+void MetalinkParserController::setTypeOfSignature(std::string type)
 {
   if(!tSignature_) {
     return;
   }
-  tSignature_->setType(type);
+  tSignature_->setType(std::move(type));
 }
 
-void MetalinkParserController::setFileOfSignature(const std::string& file)
+void MetalinkParserController::setFileOfSignature(std::string file)
 {
   if(!tSignature_) {
     return;
   }
-  tSignature_->setFile(file);
+  tSignature_->setFile(std::move(file));
 }
 
-void MetalinkParserController::setBodyOfSignature(const std::string& body)
+void MetalinkParserController::setBodyOfSignature(std::string body)
 {
   if(!tSignature_) {
     return;
   }
-  tSignature_->setBody(body);
+  tSignature_->setBody(std::move(body));
 }
 
 void MetalinkParserController::commitSignatureTransaction()
@@ -569,33 +527,32 @@ void MetalinkParserController::newMetaurlTransaction()
   tMetaurl_ = make_unique<MetalinkMetaurl>();
 }
 
-void MetalinkParserController::setURLOfMetaurl(const std::string& url)
+void MetalinkParserController::setURLOfMetaurl(std::string url)
 {
   if(!tMetaurl_) {
     return;
   }
 #ifdef ENABLE_BITTORRENT
   if(magnet::parse(url)) {
-    tMetaurl_->url = url;
+    tMetaurl_->url = std::move(url);
   } else
 #endif // ENABLE_BITTORRENT
     {
       std::string u = uri::joinUri(baseUri_, url);
       if(uri_split(nullptr, u.c_str()) == 0) {
-        tMetaurl_->url = u;
+        tMetaurl_->url = std::move(u);
       } else {
-        tMetaurl_->url = url;
+        tMetaurl_->url = std::move(url);
       }
     }
 }
 
-void MetalinkParserController::setMediatypeOfMetaurl
-(const std::string& mediatype)
+void MetalinkParserController::setMediatypeOfMetaurl(std::string mediatype)
 {
   if(!tMetaurl_) {
     return;
   }
-  tMetaurl_->mediatype = mediatype;
+  tMetaurl_->mediatype = std::move(mediatype);
 }
 
 void MetalinkParserController::setPriorityOfMetaurl(int priority)
@@ -606,12 +563,12 @@ void MetalinkParserController::setPriorityOfMetaurl(int priority)
   tMetaurl_->priority = priority;
 }
 
-void MetalinkParserController::setNameOfMetaurl(const std::string& name)
+void MetalinkParserController::setNameOfMetaurl(std::string name)
 {
   if(!tMetaurl_) {
     return;
   }
-  tMetaurl_->name = name;
+  tMetaurl_->name = std::move(name);
 }
 
 void MetalinkParserController::commitMetaurlTransaction()
