@@ -109,7 +109,7 @@ public:
   (const char* localname,
    const char* prefix,
    const char* nsUri,
-   const std::string& characters) CXX11_OVERRIDE;
+   std::string characters) CXX11_OVERRIDE;
 
   virtual void reset() CXX11_OVERRIDE;
 
@@ -159,15 +159,15 @@ public:
 
   void newEntryTransaction();
 
-  void setFileNameOfEntry(const std::string& filename);
+  void setFileNameOfEntry(std::string filename);
 
   void setFileLengthOfEntry(int64_t length);
 
-  void setVersionOfEntry(const std::string& version);
+  void setVersionOfEntry(std::string version);
 
-  void setLanguageOfEntry(const std::string& language);
+  void setLanguageOfEntry(std::string language);
 
-  void setOSOfEntry(const std::string& os);
+  void setOSOfEntry(std::string os);
 
   void setMaxConnectionsOfEntry(int maxConnections); // Metalink3Spec
 
@@ -177,11 +177,11 @@ public:
 
   void newResourceTransaction();
 
-  void setURLOfResource(const std::string& url);
+  void setURLOfResource(std::string url);
 
-  void setTypeOfResource(const std::string& type);
+  void setTypeOfResource(std::string type);
 
-  void setLocationOfResource(const std::string& location);
+  void setLocationOfResource(std::string location);
 
   void setPriorityOfResource(int priority);
 
@@ -193,9 +193,9 @@ public:
 
   void newChecksumTransaction();
 
-  void setTypeOfChecksum(const std::string& type);
+  void setTypeOfChecksum(std::string type);
 
-  void setHashOfChecksum(const std::string& md);
+  void setHashOfChecksum(std::string md);
 
   void commitChecksumTransaction();
 
@@ -205,9 +205,9 @@ public:
 
   void setLengthOfChunkChecksumV4(size_t length); // Metalink4Spec
 
-  void setTypeOfChunkChecksumV4(const std::string& type); // Metalink4Spec
+  void setTypeOfChunkChecksumV4(std::string type); // Metalink4Spec
 
-  void addHashOfChunkChecksumV4(const std::string& md); // Metalink4Spec
+  void addHashOfChunkChecksumV4(std::string md); // Metalink4Spec
 
   void commitChunkChecksumTransactionV4(); // Metalink4Spec
 
@@ -217,11 +217,11 @@ public:
 
   void setLengthOfChunkChecksum(size_t length); // Metalink3Spec
 
-  void setTypeOfChunkChecksum(const std::string& type); // Metalink3Spec
+  void setTypeOfChunkChecksum(std::string type); // Metalink3Spec
 
   void createNewHashOfChunkChecksum(size_t order); // Metalink3Spec
 
-  void setMessageDigestOfChunkChecksum(const std::string& md); // Metalink3Spec
+  void setMessageDigestOfChunkChecksum(std::string md); // Metalink3Spec
 
   void addHashOfChunkChecksum(); // Metalink3Spec
 
@@ -231,11 +231,11 @@ public:
 
   void newSignatureTransaction();
 
-  void setTypeOfSignature(const std::string& type);
+  void setTypeOfSignature(std::string type);
 
-  void setFileOfSignature(const std::string& file);
+  void setFileOfSignature(std::string file);
 
-  void setBodyOfSignature(const std::string& body);
+  void setBodyOfSignature(std::string body);
 
   void commitSignatureTransaction();
 
@@ -243,20 +243,20 @@ public:
 
   void newMetaurlTransaction();
 
-  void setURLOfMetaurl(const std::string& url);
+  void setURLOfMetaurl(std::string url);
 
-  void setMediatypeOfMetaurl(const std::string& mediatype);
+  void setMediatypeOfMetaurl(std::string mediatype);
 
   void setPriorityOfMetaurl(int priority);
 
-  void setNameOfMetaurl(const std::string& name);
+  void setNameOfMetaurl(std::string name);
 
   void commitMetaurlTransaction();
 
   void cancelMetaurlTransaction();
 
   // Only stores first 10 errors.
-  void logError(const std::string& log);
+  void logError(std::string log);
 
   const std::vector<std::string>& getErrors() const
   {
@@ -267,7 +267,7 @@ public:
 
   std::unique_ptr<Metalinker> getResult();
 
-  void setBaseUri(const std::string& uri);
+  void setBaseUri(std::string uri);
 };
 
 } //  namespace aria2
