@@ -141,6 +141,7 @@ std::unique_ptr<DiskWriterEntry> createDiskWriterEntry
 
 void MultiDiskAdaptor::resetDiskWriterEntries()
 {
+  assert(openedDiskWriterEntries_.empty());
   diskWriterEntries_.clear();
   if(getFileEntries().empty()) {
     return;
@@ -162,13 +163,13 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
         }
       } else if(fileEntry->getOffset() < lastOffset) {
         // The files which shares last piece are not needed to be
-        // allocated. They just requre DiskWriter
+        // allocated. They just require DiskWriter
         A2_LOG_DEBUG(fmt("%s needs DiskWriter",
                          fileEntry->getPath().c_str()));
         dwent->needsDiskWriter(true);
       }
     }
-    // Check shared piece backword
+    // Check shared piece backward
     lastOffset = std::numeric_limits<int64_t>::max();
     for(auto i = diskWriterEntries_.rbegin(), eoi = diskWriterEntries_.rend();
         i != eoi; ++i) {
@@ -271,18 +272,19 @@ void MultiDiskAdaptor::openExistingFile()
 
 void MultiDiskAdaptor::closeFile()
 {
-  size_t n = 0;
-  openedDiskWriterEntries_.clear();
-  for(auto& dwent : diskWriterEntries_) {
-    if(dwent->isOpen()) {
-      ++n;
-      dwent->closeFile();
+  for(auto& dwent : openedDiskWriterEntries_) {
+    auto& dw = dwent->getDiskWriter();
+    // required for unit test
+    if (!dw) {
+      continue;
     }
+    dw->closeFile();
   }
   auto& openedFileCounter = getOpenedFileCounter();
   if(openedFileCounter) {
-    openedFileCounter->reduceNumOfOpenedFile(n);
+    openedFileCounter->reduceNumOfOpenedFile(openedDiskWriterEntries_.size());
   }
+  openedDiskWriterEntries_.clear();
 }
 
 namespace {
