@@ -123,6 +123,9 @@ private:
 
   void openIfNot(DiskWriterEntry* entry, void (DiskWriterEntry::*f)());
 
+  ssize_t readData(unsigned char* data, size_t len, int64_t offset,
+                   bool dropCache);
+
   static const int DEFAULT_MAX_OPEN_FILES = 100;
 
 public:
@@ -143,6 +146,10 @@ public:
   virtual ssize_t readData(unsigned char* data, size_t len, int64_t offset)
     CXX11_OVERRIDE;
 
+  virtual ssize_t readDataDropCache(unsigned char* data, size_t len,
+                                    int64_t offset)
+    CXX11_OVERRIDE;
+
   virtual void writeCache(const WrDiskCacheEntry* entry) CXX11_OVERRIDE;
 
   virtual bool fileExists() CXX11_OVERRIDE;
