@@ -54,58 +54,59 @@ NsCookieParser::NsCookieParser() {}
 NsCookieParser::~NsCookieParser() {}
 
 namespace {
-bool parseNsCookie
-(Cookie& cookie, const std::string& cookieStr, time_t creationTime)
+std::unique_ptr<Cookie> parseNsCookie
+(const std::string& cookieStr, time_t creationTime)
 {
   std::vector<Scip> vs;
   util::splitIter(cookieStr.begin(), cookieStr.end(), std::back_inserter(vs),
                   '\t', true);
   if(vs.size() < 6) {
-    return false;
+    return nullptr;
   }
   vs[0].first = util::lstripIter(vs[0].first, vs[0].second, '.');
   if(vs[5].first == vs[5].second || vs[0].first == vs[0].second ||
      !cookie::goodPath(vs[2].first, vs[2].second)) {
-    return false;
+    return nullptr;
   }
   int64_t expiryTime;
   if(!util::parseLLIntNoThrow(expiryTime,
                               std::string(vs[4].first, vs[4].second))) {
-    return false;
+    return nullptr;
   }
   if(std::numeric_limits<time_t>::max() < expiryTime) {
     expiryTime = std::numeric_limits<time_t>::max();
   } else if(std::numeric_limits<time_t>::min() > expiryTime) {
     expiryTime = std::numeric_limits<time_t>::min();
   }
-  cookie.setName(vs[5].first, vs[5].second);
+  auto cookie = make_unique<Cookie>();
+  cookie->setName(vs[5].first, vs[5].second);
   if(vs.size() >= 7) {
-    cookie.setValue(vs[6].first, vs[6].second);
+    cookie->setValue(vs[6].first, vs[6].second);
   } else {
-    cookie.setValue(A2STR::NIL.begin(), A2STR::NIL.end());
+    cookie->setValue("");
   }
-  cookie.setExpiryTime(expiryTime == 0?
+  cookie->setExpiryTime(expiryTime == 0?
                        std::numeric_limits<time_t>::max():expiryTime);
-  // aria2 treats expiryTime == 0 means session cookie.
-  cookie.setPersistent(expiryTime != 0);
-  cookie.setDomain(vs[0].first, vs[0].second);
-  cookie.setHostOnly(util::isNumericHost(cookie.getDomain()) ||
+  // aria2 treats expiryTime == 0 means session cookie->
+  cookie->setPersistent(expiryTime != 0);
+  cookie->setDomain(vs[0].first, vs[0].second);
+  cookie->setHostOnly(util::isNumericHost(cookie->getDomain()) ||
                      !util::streq(vs[1].first, vs[1].second, "TRUE"));
-  cookie.setPath(vs[2].first, vs[2].second);
-  cookie.setSecure(util::streq(vs[3].first, vs[3].second, "TRUE"));
-  cookie.setCreationTime(creationTime);
-  return true;
+  cookie->setPath(vs[2].first, vs[2].second);
+  cookie->setSecure(util::streq(vs[3].first, vs[3].second, "TRUE"));
+  cookie->setCreationTime(creationTime);
+  return cookie;
 }
 } // namespace
 
-std::vector<Cookie> NsCookieParser::parse
+std::vector<std::unique_ptr<Cookie>> NsCookieParser::parse
 (const std::string& filename, time_t creationTime)
 {
-  BufferedFile fp(filename.c_str(), BufferedFile::READ);
+  BufferedFile fp{filename.c_str(), BufferedFile::READ};
   if(!fp) {
     throw DL_ABORT_EX(fmt("Failed to open file %s", filename.c_str()));
   }
-  std::vector<Cookie> cookies;
+  std::vector<std::unique_ptr<Cookie>> cookies;
   while(1) {
     std::string line = fp.getLine();
     if(line.empty()) {
@@ -120,9 +121,9 @@ std::vector<Cookie> NsCookieParser::parse
     if(line[0] == '#') {
       continue;
     }
-    Cookie c;
-    if(parseNsCookie(c, line, creationTime)) {
-      cookies.push_back(c);
+    auto c = parseNsCookie(line, creationTime);
+    if(c) {
+      cookies.push_back(std::move(c));
     }
   }
   return cookies;
