@@ -584,6 +584,27 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->setChangeOptionForReserved(true);
     handlers.push_back(op);
   }
+#ifdef ENABLE_SSL
+  {
+    OptionHandler* op(new ParameterOptionHandler
+                      (PREF_MIN_TLS_VERSION,
+                       TEXT_MIN_TLS_VERSION,
+                       A2_V_TLS10,
+                       { A2_V_SSL3, A2_V_TLS10, A2_V_TLS11, A2_V_TLS12 }));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+#endif // ENABLE_SSL
+  {
+    OptionHandler* op(new DefaultOptionHandler
+                      (PREF_MULTIPLE_INTERFACE,
+                       TEXT_MULTIPLE_INTERFACE,
+                       NO_DEFAULT_VALUE,
+                       "interface, IP address, hostname",
+                       OptionHandler::REQ_ARG));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new BooleanOptionHandler
                       (PREF_NO_CONF,
@@ -1485,13 +1506,23 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->setChangeOptionForReserved(true);
     handlers.push_back(op);
   }
+  {
+    OptionHandler* op(new ChecksumOptionHandler
+                      (PREF_SSH_HOST_KEY_MD,
+                       TEXT_SSH_HOST_KEY_MD,
+                       {"sha-1", "md5"}));
+    op->addTag(TAG_FTP);
+    op->setInitialOption(true);
+    op->setChangeGlobalOption(true);
+    op->setChangeOptionForReserved(true);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new DefaultOptionHandler
                       (PREF_NETRC_PATH,
-                       NO_DESCRIPTION,
+                       TEXT_NETRC_PATH,
                        util::getHomeDir()+"/.netrc",
                        PATH_TO_FILE));
-    op->hide();
     handlers.push_back(op);
   }
   // Proxy options
@@ -1700,6 +1731,15 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
 #endif // ENABLE_BITTORRENT || ENABLE_METALINK
   // BitTorrent Specific Options
 #ifdef ENABLE_BITTORRENT
+  {
+    OptionHandler* op(new BooleanOptionHandler
+                      (PREF_BT_DETACH_SEED_ONLY,
+                       TEXT_BT_DETACH_SEED_ONLY,
+                       A2_V_FALSE,
+                       OptionHandler::OPT_ARG));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new BooleanOptionHandler
                       (PREF_BT_ENABLE_LPD,
@@ -1737,6 +1777,18 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->setChangeOptionForReserved(true);
     handlers.push_back(op);
   }
+  {
+    OptionHandler* op(new BooleanOptionHandler
+                      (PREF_BT_FORCE_ENCRYPTION,
+                       TEXT_BT_FORCE_ENCRYPTION,
+                       A2_V_FALSE,
+                       OptionHandler::OPT_ARG));
+    op->addTag(TAG_BITTORRENT);
+    op->setInitialOption(true);
+    op->setChangeGlobalOption(true);
+    op->setChangeOptionForReserved(true);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new NumberOptionHandler
                       (PREF_BT_KEEP_ALIVE_INTERVAL,
