@@ -57,34 +57,34 @@ public:
 private:
   RequestGroup* requestGroup_;
 
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<BtRuntime> btRuntime_;
 
-  SharedHandle<PieceStorage> pieceStorage_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
 
-  SharedHandle<PeerStorage> peerStorage_;
+  std::shared_ptr<PeerStorage> peerStorage_;
 
   Seq sequence_;
-  SharedHandle<BtInteractive> btInteractive_;
+  std::unique_ptr<BtInteractive> btInteractive_;
 
-  const SharedHandle<Option>& getOption() const;
+  const std::shared_ptr<Option>& getOption() const;
 protected:
-  virtual bool executeInternal();
-  virtual bool prepareForNextPeer(time_t wait);
-  virtual void onAbort();
-  virtual void onFailure(const Exception& err);
-  virtual bool exitBeforeExecute();
+  virtual bool executeInternal() CXX11_OVERRIDE;
+  virtual bool prepareForNextPeer(time_t wait) CXX11_OVERRIDE;
+  virtual void onAbort() CXX11_OVERRIDE;
+  virtual void onFailure(const Exception& err) CXX11_OVERRIDE;
+  virtual bool exitBeforeExecute() CXX11_OVERRIDE;
 public:
   PeerInteractionCommand(cuid_t cuid,
                          RequestGroup* requestGroup,
-                         const SharedHandle<Peer>& peer,
+                         const std::shared_ptr<Peer>& peer,
                          DownloadEngine* e,
-                         const SharedHandle<BtRuntime>& btRuntime,
-                         const SharedHandle<PieceStorage>& pieceStorage,
-                         const SharedHandle<PeerStorage>& peerStorage,
-                         const SharedHandle<SocketCore>& s,
+                         const std::shared_ptr<BtRuntime>& btRuntime,
+                         const std::shared_ptr<PieceStorage>& pieceStorage,
+                         const std::shared_ptr<PeerStorage>& peerStorage,
+                         const std::shared_ptr<SocketCore>& s,
                          Seq sequence,
-                         const SharedHandle<PeerConnection>& peerConnection =
-                         SharedHandle<PeerConnection>());
+                         std::unique_ptr<PeerConnection> peerConnection =
+                         nullptr);
 
   virtual ~PeerInteractionCommand();
 };
