@@ -39,14 +39,19 @@
 
 #include <deque>
 #include <vector>
+#include <set>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "TransferStat.h"
+#include "Command.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
 class Peer;
 
+typedef std::set<std::shared_ptr<Peer>, RefLess<Peer> > PeerSet;
+
 class PeerStorage {
 public:
   virtual ~PeerStorage() {}
@@ -55,33 +60,22 @@ public:
    * Adds new peer to the internal peer list.
    * If the peer is added successfully, returns true. Otherwise returns false.
    */
-  virtual bool addPeer(const SharedHandle<Peer>& peer) = 0;
+  virtual bool addPeer(const std::shared_ptr<Peer>& peer) = 0;
 
   /**
    * Adds all peers in peers to internal peer list.
    */
-  virtual void addPeer(const std::vector<SharedHandle<Peer> >& peers) = 0;
+  virtual void addPeer(const std::vector<std::shared_ptr<Peer> >& peers) = 0;
 
   /**
-   * Returns internal peer list.
+   * Returns the number of peers, including used and unused ones.
    */
-  virtual const std::deque<SharedHandle<Peer> >& getPeers() = 0;
-
-
-  /**
-   * Returns the number of peers.
-   */
-  virtual size_t countPeer() const = 0;
+  virtual size_t countAllPeer() const = 0;
 
   /**
    * Returns internal dropped peer list.
    */
-  virtual const std::deque<SharedHandle<Peer> >& getDroppedPeers() = 0;
-
-  /**
-   * Returns one of the unused peers.
-   */
-  virtual SharedHandle<Peer> getUnusedPeer() = 0;
+  virtual const std::deque<std::shared_ptr<Peer> >& getDroppedPeers() = 0;
 
   /**
    * Returns true if at least one unused peer exists.
@@ -90,9 +84,9 @@ public:
   virtual bool isPeerAvailable() = 0;
 
   /**
-   * Returns the list of peers which are currently connected from localhost.
+   * Returns used peer set.
    */
-  virtual void getActivePeers(std::vector<SharedHandle<Peer> >& peers) = 0;
+  virtual const PeerSet& getUsedPeers() = 0;
 
   /**
    * Returns true if peer with ipaddr should be ignored because, for
@@ -105,10 +99,17 @@ public:
    */
   virtual void addBadPeer(const std::string& ipaddr) = 0;
 
+  /**
+   * Moves first peer in unused peer list to used peer set and calls
+   * Peer::usedBy(cuid). If there is no peer available, returns
+   * std::shared_ptr<Peer>().
+   */
+  virtual std::shared_ptr<Peer> checkoutPeer(cuid_t cuid) = 0;
+
   /**
    * Tells PeerStorage object that peer is no longer used in the session.
    */
-  virtual void returnPeer(const SharedHandle<Peer>& peer) = 0;
+  virtual void returnPeer(const std::shared_ptr<Peer>& peer) = 0;
 
   virtual bool chokeRoundIntervalElapsed() = 0;
 
