@@ -44,13 +44,11 @@ namespace aria2 {
 class PostDownloadHandler:public DownloadHandler
 {
 public:
-  PostDownloadHandler() {}
-
   virtual ~PostDownloadHandler() {}
 
   virtual void
-  getNextRequestGroups(std::vector<std::shared_ptr<RequestGroup> >& groups,
-                       RequestGroup* requestGroup) = 0;
+  getNextRequestGroups(std::vector<std::shared_ptr<RequestGroup>>& groups,
+                       RequestGroup* requestGroup) const = 0;
 };
 
 } // namespace aria2
