@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,35 +34,34 @@
 /* copyright --> */
 #include "RealtimeCommand.h"
 #include "DownloadEngine.h"
-#include "Exception.h"
+#include "RecoverableException.h"
 #include "RequestGroup.h"
-#include "DownloadContext.h"
 
 namespace aria2 {
 
-RealtimeCommand::RealtimeCommand(int cuid, RequestGroup* requestGroup,
-				 DownloadEngine* e):
+RealtimeCommand::RealtimeCommand(cuid_t cuid, RequestGroup* requestGroup,
+                                 DownloadEngine* e):
   Command(cuid),
-  _requestGroup(requestGroup),
-  _e(e)
+  requestGroup_(requestGroup),
+  e_(e)
 {
   setStatusRealtime();
 
-  _requestGroup->increaseNumCommand();
+  requestGroup_->increaseNumCommand();
 }
 
 RealtimeCommand::~RealtimeCommand()
 {
-  _requestGroup->decreaseNumCommand();
+  requestGroup_->decreaseNumCommand();
 }
 
 bool RealtimeCommand::execute()
 {
   setStatusRealtime();
-  _e->setNoWait(true);
+  e_->setNoWait(true);
   try {
     return executeInternal();
-  } catch(Exception& e) {
+  } catch(RecoverableException& e) {
     bool r =  handleException(e);
     return r;
   }
