@@ -62,7 +62,7 @@ public:
 
   virtual ~RealtimeCommand();
 
-  virtual bool execute();
+  virtual bool execute() CXX11_OVERRIDE;
 
   virtual bool executeInternal() = 0;
 
