@@ -59,16 +59,16 @@ public:
 
   virtual ~SingleFileAllocationIterator();
 
-  virtual void allocateChunk();
+  virtual void allocateChunk() CXX11_OVERRIDE;
 
-  virtual bool finished();
+  virtual bool finished() CXX11_OVERRIDE;
 
-  virtual int64_t getCurrentLength()
+  virtual int64_t getCurrentLength() CXX11_OVERRIDE
   {
     return offset_;
   }
 
-  virtual int64_t getTotalLength()
+  virtual int64_t getTotalLength() CXX11_OVERRIDE
   {
     return totalLength_;
   }
