@@ -41,8 +41,9 @@
 namespace aria2 {
 
 UTMetadataRejectExtensionMessage::UTMetadataRejectExtensionMessage
-(uint8_t extensionMessageID):
-  UTMetadataExtensionMessage(extensionMessageID) {}
+(uint8_t extensionMessageID)
+  : UTMetadataExtensionMessage{extensionMessageID}
+{}
 
 std::string UTMetadataRejectExtensionMessage::getPayload()
 {
@@ -54,7 +55,8 @@ std::string UTMetadataRejectExtensionMessage::getPayload()
 
 std::string UTMetadataRejectExtensionMessage::toString() const
 {
-  return strconcat("ut_metadata reject piece=", util::uitos(getIndex()));
+  return fmt("ut_metadata reject piece=%lu",
+             static_cast<unsigned long>(getIndex()));
 }
 
 void UTMetadataRejectExtensionMessage::doReceivedAction()
