@@ -211,7 +211,8 @@ WebSocketSession::WebSocketSession(const std::shared_ptr<SocketCore>& socket,
   : socket_(socket),
     e_(e),
     ignorePayload_(false),
-    receivedLength_(0)
+    receivedLength_(0),
+    command_(nullptr)
 {
   wslay_event_callbacks callbacks;
   memset(&callbacks, 0, sizeof(wslay_event_callbacks));
