@@ -138,7 +138,7 @@ public:
   virtual ~WinTLSSession();
 
   // Initializes SSL/TLS session. The |sockfd| is the underlying
-  // tranport socket. This function returns TLS_ERR_OK if it
+  // transport socket. This function returns TLS_ERR_OK if it
   // succeeds, or TLS_ERR_ERROR.
   virtual int init(sock_t sockfd) CXX11_OVERRIDE;
 
@@ -161,12 +161,12 @@ public:
 
   // Sends |data| with length |len|. This function returns the number
   // of bytes sent if it succeeds, or TLS_ERR_WOULDBLOCK if the
-  // underlying tranport blocks, or TLS_ERR_ERROR.
+  // underlying transport blocks, or TLS_ERR_ERROR.
   virtual ssize_t writeData(const void* data, size_t len) CXX11_OVERRIDE;
 
   // Receives data into |data| with length |len|. This function returns
   // the number of bytes received if it succeeds, or TLS_ERR_WOULDBLOCK
-  // if the underlying tranport blocks, or TLS_ERR_ERROR.
+  // if the underlying transport blocks, or TLS_ERR_ERROR.
   virtual ssize_t readData(void* data, size_t len) CXX11_OVERRIDE;
 
   // Performs client side handshake. The |hostname| is the hostname of
@@ -176,12 +176,13 @@ public:
   // When returning TLS_ERR_ERROR, provide certificate validation error
   // in |handshakeErr|.
   virtual int tlsConnect(const std::string& hostname,
+                         TLSVersion& version,
                          std::string& handshakeErr) CXX11_OVERRIDE;
 
   // Performs server side handshake. This function returns TLS_ERR_OK
   // if it succeeds, or TLS_ERR_WOULDBLOCK if the underlying transport
   // blocks, or TLS_ERR_ERROR.
-  virtual int tlsAccept() CXX11_OVERRIDE;
+  virtual int tlsAccept(TLSVersion& version) CXX11_OVERRIDE;
 
   // Returns last error string
   virtual std::string getLastErrorString() CXX11_OVERRIDE;
@@ -196,7 +197,7 @@ private:
   // Buffer for already encrypted writes
   wintls::Buffer writeBuf_;
   // While the writeBuf_ holds encrypted messages, writeBuffered_ has the
-  // corresponding size of unencrpted data used to procude the messages.
+  // corresponding size of unencrypted data used to produce the messages.
   size_t writeBuffered_;
   // Buffer for still encrypted reads
   wintls::Buffer readBuf_;
