@@ -32,8 +32,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION(DHTFindNodeReplyMessageTest);
 
 void DHTFindNodeReplyMessageTest::testGetBencodedMessage()
 {
-  SharedHandle<DHTNode> localNode(new DHTNode());
-  SharedHandle<DHTNode> remoteNode(new DHTNode());
+  std::shared_ptr<DHTNode> localNode(new DHTNode());
+  std::shared_ptr<DHTNode> remoteNode(new DHTNode());
 
   unsigned char tid[DHT_TRANSACTION_ID_LENGTH];
   util::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
@@ -42,7 +42,7 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage()
   DHTFindNodeReplyMessage msg(AF_INET, localNode, remoteNode, transactionID);
   msg.setVersion("A200");
   std::string compactNodeInfo;
-  SharedHandle<DHTNode> nodes[8];
+  std::shared_ptr<DHTNode> nodes[8];
   for(size_t i = 0; i < DHTBucket::K; ++i) {
     nodes[i].reset(new DHTNode());
     nodes[i]->setIPAddress("192.168.0."+util::uitos(i+1));
@@ -56,7 +56,7 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage()
       std::string(&buf[0], &buf[COMPACT_LEN_IPV4]);
   }
   msg.setClosestKNodes
-    (std::vector<SharedHandle<DHTNode> >(&nodes[0], &nodes[DHTBucket::K]));
+    (std::vector<std::shared_ptr<DHTNode> >(&nodes[0], &nodes[DHTBucket::K]));
 
   std::string msgbody = msg.getBencodedMessage();
 
@@ -64,18 +64,18 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage()
   dict.put("t", transactionID);
   dict.put("v", "A200");
   dict.put("y", "r");
-  SharedHandle<Dict> rDict = Dict::g();
+  auto rDict = Dict::g();
   rDict->put("id", String::g(localNode->getID(), DHT_ID_LENGTH));
   rDict->put("nodes", compactNodeInfo);
-  dict.put("r", rDict);
+  dict.put("r", std::move(rDict));
 
   CPPUNIT_ASSERT_EQUAL(bencode2::encode(&dict), msgbody);
 }
 
 void DHTFindNodeReplyMessageTest::testGetBencodedMessage6()
 {
-  SharedHandle<DHTNode> localNode(new DHTNode());
-  SharedHandle<DHTNode> remoteNode(new DHTNode());
+  std::shared_ptr<DHTNode> localNode(new DHTNode());
+  std::shared_ptr<DHTNode> remoteNode(new DHTNode());
 
   unsigned char tid[DHT_TRANSACTION_ID_LENGTH];
   util::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
@@ -84,7 +84,7 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage6()
   DHTFindNodeReplyMessage msg(AF_INET6, localNode, remoteNode, transactionID);
   msg.setVersion("A200");
   std::string compactNodeInfo;
-  SharedHandle<DHTNode> nodes[8];
+  std::shared_ptr<DHTNode> nodes[8];
   for(size_t i = 0; i < DHTBucket::K; ++i) {
     nodes[i].reset(new DHTNode());
     nodes[i]->setIPAddress("2001::000"+util::uitos(i+1));
@@ -98,7 +98,7 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage6()
       std::string(&buf[0], &buf[COMPACT_LEN_IPV6]);
   }
   msg.setClosestKNodes
-    (std::vector<SharedHandle<DHTNode> >(&nodes[0], &nodes[DHTBucket::K]));
+    (std::vector<std::shared_ptr<DHTNode> >(&nodes[0], &nodes[DHTBucket::K]));
 
   std::string msgbody = msg.getBencodedMessage();
 
@@ -106,10 +106,10 @@ void DHTFindNodeReplyMessageTest::testGetBencodedMessage6()
   dict.put("t", transactionID);
   dict.put("v", "A200");
   dict.put("y", "r");
-  SharedHandle<Dict> rDict = Dict::g();
+  auto rDict = Dict::g();
   rDict->put("id", String::g(localNode->getID(), DHT_ID_LENGTH));
   rDict->put("nodes6", compactNodeInfo);
-  dict.put("r", rDict);
+  dict.put("r", std::move(rDict));
 
   CPPUNIT_ASSERT_EQUAL(bencode2::encode(&dict), msgbody);
 }
