@@ -29,7 +29,7 @@ void DHTTaskExecutorTest::testUpdate()
     std::shared_ptr<MockDHTTask>(new MockDHTTask(rn))
   };
   tasks[1]->finished_ = true;
-  for(size_t i = 0; i < A2_ARRAY_LEN(tasks); ++i) {
+  for(size_t i = 0; i < arraySize(tasks); ++i) {
     tex.addTask(tasks[i]);
   }
   CPPUNIT_ASSERT_EQUAL((size_t)0, tex.getExecutingTaskSize());
