@@ -53,9 +53,7 @@ class HttpResponseTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testRetrieveCookie);
   CPPUNIT_TEST(testSupportsPersistentConnection);
   CPPUNIT_TEST(testGetMetalinKHttpEntries);
-#ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_TEST(testGetDigest);
-#endif // ENABLE_MESSAGE_DIGEST
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -88,9 +86,7 @@ public:
   void testRetrieveCookie();
   void testSupportsPersistentConnection();
   void testGetMetalinKHttpEntries();
-#ifdef ENABLE_MESSAGE_DIGEST
   void testGetDigest();
-#endif // ENABLE_MESSAGE_DIGEST
 };
 
 
@@ -220,16 +216,49 @@ void HttpResponseTest::testGetRedirectURI_with_Location()
 void HttpResponseTest::testIsRedirect()
 {
   HttpResponse httpResponse;
-  auto httpHeader = make_unique<HttpHeader>();
-  httpHeader->setStatusCode(200);
-  httpHeader->put(HttpHeader::LOCATION,
-                  "http://localhost/download/aria2-1.0.0.tar.bz2");
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
 
-  httpResponse.setHttpHeader(std::move(httpHeader));
+  httpResponse.getHttpHeader()->setStatusCode(301);
   CPPUNIT_ASSERT(!httpResponse.isRedirect());
 
+  httpResponse.getHttpHeader()->setStatusCode(200);
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LOCATION,
+     "http://localhost/download/aria2-1.0.0.tar.bz2");
+
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(300);
+  CPPUNIT_ASSERT(httpResponse.isRedirect());
+
   httpResponse.getHttpHeader()->setStatusCode(301);
   CPPUNIT_ASSERT(httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(302);
+  CPPUNIT_ASSERT(httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(303);
+  CPPUNIT_ASSERT(httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(304);
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(305);
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(306);
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(307);
+  CPPUNIT_ASSERT(httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(308);
+  CPPUNIT_ASSERT(httpResponse.isRedirect());
+
+  httpResponse.getHttpHeader()->setStatusCode(309);
+  CPPUNIT_ASSERT(!httpResponse.isRedirect());
 }
 
 void HttpResponseTest::testIsTransferEncodingSpecified()
@@ -333,15 +362,18 @@ void HttpResponseTest::testValidateResponse()
     httpResponse.validateResponse();
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
+    // success
   }
 
-  httpResponse.getHttpHeader()->put
-    (HttpHeader::LOCATION,
-     "http://localhost/archives/aria2-1.0.0.tar.bz2");
-  try {
+  httpResponse.getHttpHeader()->put(HttpHeader::LOCATION, "http://a/b");
+  httpResponse.validateResponse();
+
+  httpResponse.getHttpHeader()->setStatusCode(201);
+  try{
     httpResponse.validateResponse();
+    CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
-    CPPUNIT_FAIL("exception must not be thrown.");
+    // success
   }
 }
 
@@ -631,7 +663,6 @@ void HttpResponseTest::testGetMetalinKHttpEntries()
   CPPUNIT_ASSERT(e.geo.empty());
 }
 
-#ifdef ENABLE_MESSAGE_DIGEST
 void HttpResponseTest::testGetDigest()
 {
   HttpResponse httpResponse;
@@ -654,24 +685,17 @@ void HttpResponseTest::testGetDigest()
      "MD5=LJDK2+9ClF8Nz/K5WZd/+A==");
   std::vector<Checksum> result;
   httpResponse.getDigest(result);
-#ifdef USE_INTERNAL_MD
-  CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
-#else
   CPPUNIT_ASSERT_EQUAL((size_t)3, result.size());
-#endif
 
   Checksum c = result[0];
-#ifndef USE_INTERNAL_MD
   CPPUNIT_ASSERT_EQUAL(std::string("sha-256"), c.getHashType());
   CPPUNIT_ASSERT_EQUAL(std::string("f83f271ae773dc6fe4a6454a41e0eb237c43e7bbf451e426cc60993a4d379ec5"),
                        util::toHex(c.getDigest()));
 
   c = result[1];
-#endif
   CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c.getHashType());
   CPPUNIT_ASSERT_EQUAL(std::string("f36003f22b462ffa184390533c500d8989e9f681"),
                        util::toHex(c.getDigest()));
 }
-#endif // ENABLE_MESSAGE_DIGEST
 
 } // namespace aria2
