@@ -11,7 +11,7 @@ namespace aria2 {
 class MessageDigestHelperTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(MessageDigestHelperTest);
-  CPPUNIT_TEST(testHexDigestDiskWriter);
+  CPPUNIT_TEST(testDigestDiskWriter);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -19,24 +19,26 @@ public:
   void setUp() {
   }
 
-  void testHexDigestDiskWriter();
+  void testDigestDiskWriter();
 };
 
 
 CPPUNIT_TEST_SUITE_REGISTRATION( MessageDigestHelperTest );
 
-void MessageDigestHelperTest::testHexDigestDiskWriter() {
-  SharedHandle<DefaultDiskWriter> diskio
-    (new DefaultDiskWriter(A2_TEST_DIR"/4096chunk.txt"));
+void MessageDigestHelperTest::testDigestDiskWriter() {
+  auto diskio = std::make_shared<DefaultDiskWriter>
+    (A2_TEST_DIR"/4096chunk.txt");
   diskio->enableReadOnly();
   diskio->openExistingFile();
   CPPUNIT_ASSERT_EQUAL(std::string("608cabc0f2fa18c260cafd974516865c772363d5"),
-                       message_digest::hexDigest
-                       (MessageDigest::sha1(), diskio, 0, 4096));
+                       util::toHex(message_digest::digest
+                                   (MessageDigest::sha1().get(),
+                                    diskio, 0, 4096)));
 
   CPPUNIT_ASSERT_EQUAL(std::string("7a4a9ae537ebbbb826b1060e704490ad0f365ead"),
-                       message_digest::hexDigest
-                       (MessageDigest::sha1(), diskio, 5, 100));
+                       util::toHex(message_digest::digest
+                                   (MessageDigest::sha1().get(),
+                                    diskio, 5, 100)));
 }
 
 } // namespace aria2
