@@ -27,6 +27,7 @@ public:
   void tearDown() {}
 
   void testParseRFC1123();
+  void testParseRFC1123Alt();
   void testParseRFC850();
   void testParseRFC850Ext();
   void testParseAsctime();
@@ -45,6 +46,12 @@ void TimeTest::testParseRFC1123()
   CPPUNIT_ASSERT_EQUAL((time_t)1220714793, t1.getTime());
 }
 
+void TimeTest::testParseRFC1123Alt()
+{
+  Time t1 = Time::parseRFC1123Alt("Sat, 06 Sep 2008 15:26:33 +0000");
+  CPPUNIT_ASSERT_EQUAL((time_t)1220714793, t1.getTime());
+}
+
 void TimeTest::testParseRFC850()
 {
   Time t1 = Time::parseRFC850("Saturday, 06-Sep-08 15:26:33 GMT");
